==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/qt4_docking_notify/translations/qt4_docking_notify_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Notify</source>
        <translation>Oznámit</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Oznámení</translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation>Bublina ikony v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Časové omezení</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n sekunda</numerusform>
            <numerusform>%n sekundy</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation>Ikona oznámení</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Vážné</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Qt4NotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation>Nastavit</translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation>Nastavení vzhledu bubliny ikony v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation>
%&amp;t - název (např. Nová zpráva) %&amp;m - text oznámení (např. Zpráva od Jana), %&amp;d - details (např. Citace zprávy),
%&amp;i - ikona oznámení</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/qt4_docking_notify/translations/qt4_docking_notify_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Notify</source>
        <translation>Oznámit</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Oznámení</translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation>Bublina ikony v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Časové omezení</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n sekunda</numerusform><numerusform>%n sekundy</numerusform><numerusform>%n sekund</numerusform></translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation>Ikona oznámení</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informace</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Vážné</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation>Žádná ikona</translation>
    </message>
</context>
<context>
    <name>Qt4NotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation>Nastavit</translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation>Nastavení vzhledu bubliny ikony v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation>
%&amp;t - název (např. Nová zpráva) %&amp;m - text oznámení (např. Zpráva od Jana), %&amp;d - details (např. Citace zprávy),
%&amp;i - ikona oznámení</translation>
    </message>
</context>
</TS>
